<?php

/**
* Data Transaction / MySQL Improved (mysqli) Plugin
* A MySQLi plugin to the (data_trans) class
* @package		phpOpenFW
* @subpackage 	Database_Tools
* @author 		Christian J. Clark
* @copyright	Copyright (c) Christian J. Clark
* @license		http://www.gnu.org/licenses/gpl-2.0.txt
* @access		private
* @version 		Started: 6-3-2009 updated: 1-20-2010
*/

//***************************************************************
/**
 * dt_mysqli Class
 * @package		phpOpenFW
 * @subpackage	Database_Tools
 * @access		private
 */
//***************************************************************
class dt_mysqli extends dt_structure
{

    /**
	* Opens a connection to the specified data source based on the data source type
	**/
	//*************************************************************************
	// Make a connection to the given source and store the handle
	//*************************************************************************
	public function open()
	{
		if (!$this->port) { $this->port = 3306; }
        $this->handle = @new mysqli($this->server, $this->user, $this->pass, $this->source, $this->port);

        if ($this->handle->connect_errno) {
        	$this->connection_error($this->handle->connect_error);
			return false;
        }
        else {
			// Flag Connection as Open       
	        $this->conn_open = true;
	        return true;
		}
	}
	
	/**
	* Closes a connection to the specified data source based on the data source type
	**/
	//*************************************************************************
	// Close the connection to the data source
	//*************************************************************************
    public function close()
	{
		if ($this->conn_open) { $this->handle->close(); }
		$this->conn_open = false;
	}

	/**
	* Executes a query based on the data source type
	* @param mixed MySQL: SQL Statement
	**/
	//*************************************************************************
	// Execute a query and store the record set
	//*************************************************************************
	public function query($query)
	{
		// Check for Open Connection
		if (!$this->is_open()) { return false; }

		// Execute Query
        $this->rsrc_id = $this->handle->query($query);
        if ($this->rsrc_id && gettype($this->rsrc_id) != 'boolean') {
            $this->num_rows = $this->rsrc_id->num_rows;
            while($row = $this->rsrc_id->fetch_assoc()){
                array_push($this->result, $row);
            }
        }

        // Last Insert ID
        $this->last_id = $this->handle->insert_id;

        // Check for error
        $is_error = $this->check_and_print_error($this->handle);
		if ($is_error) { return false; }

	}

	//*************************************************************************
	/**
	* Check for Database Error
	**/
	//*************************************************************************
	// Check and Print Database Error
	//*************************************************************************
	private function check_and_print_error($rsrc=false)
	{
		if (!$rsrc) { return false; }
		else if ($rsrc->errno) {
			$this->print_error($rsrc->errno, $rsrc->error);
			return true;
		}
		else { return false; }
	}

	//*************************************************************************
	/**
	* Print Database Error
	**/
	//*************************************************************************
	// Print Database Error
	//*************************************************************************
	private function print_error($errno=false, $error=false)
	{
		if (!$errno || !$error) { return false; }
		else {
			// Check if this is web environment or not
			$msg_break = (isset($_SERVER)) ? ("<br/>\n") : ("\n");
			$error_msg = 'MySQL Error: ' . $msg_break;
			$error_msg .= '[Code] -> ' . $errno . $msg_break;
			$error_msg .= '[Message] -> ' . $error . $msg_break;
			$this->gen_error($error_msg);
			return true;
		}
	}

}

?>
