<?php

/**
* Data Transaction / Oracle Plugin
* A Oracle plugin to the (data_trans) class
* @package		phpOpenFW
* @subpackage 	Database_Tools
* @author 		Christian J. Clark
* @copyright	Copyright (c) Christian J. Clark
* @license		http://www.gnu.org/licenses/gpl-2.0.txt
* @access		private
* @version 		Started: 6-3-2009 updated: 1-20-2010
*/

//***************************************************************
/**
 * dt_oracle Class
 * @package		phpOpenFW
 * @subpackage	Database_Tools
 * @access		private
 */
//***************************************************************
class dt_oracle extends dt_structure
{

    /**
	* Opens a connection to the specified data source based on the data source type
	**/
	//*************************************************************************
	// Make a connection to the given source and store the handle
	//*************************************************************************
	public function open()
	{
		// Port
		if (!$this->port) { $this->port = 1521; }

		// Connection String
		if ($this->conn_str !== false) {
			$db_params = $this->conn_str;
		}
		else {
			$db_params = "(DESCRIPTION =(ADDRESS = (PROTOCOL = TCP)(HOST = $this->server)(PORT = $this->port))\n";
			$db_params .= "(CONNECT_DATA = (SERVER = DEDICATED)(SERVICE_NAME = )(INSTANCE_NAME = )))";
		}

		// Connect
        $this->handle = oci_connect($this->user, $this->pass, $db_params);

        // Check for and print error
        if ($oracle_error=oci_error()) {
        	$this->print_error($oracle_error);
			return false;
        }
		else {
			// Flag Connection as Open       
	        $this->conn_open = true;
	        return true;
		}
	}
	
	/**
	* Closes a connection to the specified data source based on the data source type
	**/
	//*************************************************************************
	// Close the connection to the data source
	//*************************************************************************
    public function close()
	{
		if ($this->handle) { oci_close($this->handle); }
		$this->conn_open = false;
	}

	/**
	* Executes a query based on the data source type
	* @param mixed Oracle: SQL Statement
	**/
	//*************************************************************************
	// Execute a query and store the record set
	//*************************************************************************
	public function query($query)
	{
		// Check for Open Connection
		if (!$this->is_open()) { return false; }

		// Parse Query
		$this->rsrc_id = oci_parse($this->handle, $query);

		// Execute Query
        @oci_execute($this->rsrc_id);

        // Check for error
        $is_error = $this->check_and_print_error($this->rsrc_id);
		if ($is_error) { return false; }

		// Fetch Associative Record Set
        if ($this->rsrc_id && gettype($this->rsrc_id) != 'boolean') {
            $this->num_rows = oci_num_rows($this->rsrc_id);
            $this->num_fields = oci_num_fields($this->rsrc_id);
            while ($row = @oci_fetch_assoc($this->rsrc_id)) {
                array_push($this->result, $row);
            }
        }

        // Last Insert ID
        $this->last_id = NULL;

        // Check for error
        $is_error = $this->check_and_print_error($this->rsrc_id);
		if ($is_error) { return false; }
	}
	
	//*************************************************************************
	/**
	* Check and Print Database Error
	**/
	//*************************************************************************
	// Check and Print Database Error
	//*************************************************************************
	private function check_and_print_error($rsrc=false)
	{
		if (!$rsrc) { return false; }
		else if ($error = oci_error($rsrc)) {
			$this->print_error($error);
			return true;
		}
		else { return false; }
	}

	//*************************************************************************
	/**
	* Print Database Error
	**/
	//*************************************************************************
	// Print Database Error
	//*************************************************************************
	private function print_error($error=false)
	{
		if (!$error) { return false; }
		else {
			// Check if this is web environment or not
			$msg_break = (isset($_SERVER)) ? ("<br/>\n") : ("\n");
			$error_msg = 'Oracle Error: ' . $msg_break;
			$error_msg .= '[Code] -> ' . $error['code'] . $msg_break;
			$error_msg .= '[Message] -> ' . $error['message'] . $msg_break;
			//$error_msg .= '[SQL] -> ' . $error['sqltext'] . $msg_break;
			$this->gen_error($error_msg);
			return true;
		}
	}

}

?>
