<?php
//**************************************************************************************//
//**************************************************************************************//
/**
* Quick Database Actions plugin
*
* @package		phpOpenFW
* @subpackage	Plugin
* @author 		Christian J. Clark
* @copyright	Copyright (c) Christian J. Clark
* @license		http://www.gnu.org/licenses/gpl-2.0.txt
* @version 		Started: 3-15-2007, Last updated: 1-16-2010
**/
//**************************************************************************************//
//**************************************************************************************//

//**************************************************************************************//
/**
* Pull a list of records from a table
* 
* @param string Index of DB config
* @param string SQL Statement
* @param string Return Format to return ("", "key", "key:value")
* @return Array Record Set
*/
//**************************************************************************************//
function qdb_list($db_config, $strsql, $return_format='')
{
	// New Data Transaction
	$data1 = new data_trans($db_config);
	
	// Execute Query
	$data1->data_query($strsql);
	
	// Return Result Set
	$rf_arr = explode(':', $return_format);
	if (empty($rf_arr[0])) { unset($rf_arr[0]); }
	if (count($rf_arr) < 1) {
		return $data1->data_assoc_result();
	}
	else if (count($rf_arr) == 1) {
		return $data1->data_key_assoc($rf_arr[0]);
	}
	else if (count($rf_arr) > 1) {
		return $data1->data_key_val($rf_arr[0], $rf_arr[1]);
	}
}

//**************************************************************************************//
/**
* Safe Delete Row or Rows from a table
* 
* @param string Index of DB config
* @param string Database Table
* @param string Where clause (must not be empty, in order for execution to take place)
* @return Array Record Set
*/
//**************************************************************************************//
function qdb_delete($db_config, $db_table, $where='')
{
	if ($where == '') {
		trigger_error('Error: qdb_delete(): No where clause specified!');
		return false;
	}

	// New Data Transaction
	$data1 = new data_trans($db_config);
	trim($where);
	
	if (!empty($where)) {
		$strsql = "delete from $db_table where $where";		
	}
	
	if (!empty($where) && isset($strsql)) {
		// Execute Query
		$data1->data_query($strsql);
	}
	
	return true;
}

//**************************************************************************************//
/**
* Quick Database Field Lookup
*/
//**************************************************************************************//
function qdb_lookup($data_source, $sql, $fields='')
{
	// Check if fields are not specified
	if ($fields == '') {
		trigger_error('ERROR: qdb_lookup(): No return fields specified!!');
	}

	// Execute Query
	$data1 = new data_trans($data_source);
	$data1->data_query($sql);
	
	// Pull result set
	$result = $data1->data_assoc_result();
	
	// If result set empty, return false
	if (count($result) <= 0) { return false; }
	// Else Check field values
	else {
		// Multiple fields specified
		if (is_array($fields)) {
			$return_vals = array();
			foreach ($fields as $index) {
				if (array_key_exists($index, $result[0])) {
					$return_vals[$index] = $result[0][$index];
				}
				else {
					trigger_error("ERROR: qdb_lookup(): Field '$index' does not exist in record set!!");
				}
			}
		}
		// One field only
		else {
			if (array_key_exists($fields, $result[0])) { return $result[0][$fields]; }
			else {
				trigger_error("ERROR: qdb_lookup(): Field '$fields' does not exist in record set!!");
			}
		}
	}
}

?>
